- VGUIMenu
- Geiger
- Train
- HudText
- SayText
- SayText2
- TextMsg
- HudMsg
- ResetHud
- GameTitle
- Shake
- Fade
- Rumble
- CloseCaption
- CloseCaptionDirect
- SendAudio
- RawAudio
- VoiceMask
- RequestState
- Damage
- RadioText
- HintText
- KeyHintText
- ProcessSpottedEntityUpdate
- ReloadEffect
- AdjustMoney
- UpdateTeamMoney
- StopSpectatorMode
- KillCam
- DesiredTimescale
- CurrentTimescale
- AchievementEvent
- MatchEndConditions
- DisconnectToLobby
- PlayerStatsUpdate
- DisplayInventory
- WarmupHasEnded
- ClientInfo
- XRankGet
- XRankUpd
- CallVoteFailed
- VoteStart
- VotePass
- VoteFailed
